@@ -2,14 +2,9 @@ use super::ChangeSet;
 use crate::config::Project;
 use crate::ext::sync::{wait_interruptible, CommandResult};
 use crate::ext::{fs, PathBufExt};
+use crate::internal_prelude::*;
+use crate::logger::GRAY;
 use crate::signal::{Interrupt, Outcome, Product};
-use crate::{
-    ext::{
-        anyhow::{Context, Result},
-        exe::Exe,
-    },
-    logger::GRAY,
-};
 use camino::Utf8Path;
 use std::sync::Arc;
 use swc::config::IsModule;
@@ -17,8 +12,9 @@ use swc::JsMinifyExtras;
 use swc::{config::JsMinifyOptions, try_with_handler, BoolOrDataConfig};
 use swc_common::{FileName, SourceMap, GLOBALS};
 use tokio::process::Child;
-use tokio::{process::Command, sync::broadcast, task::JoinHandle};
+use tokio::{process::Command, task::JoinHandle};
 use wasm_bindgen_cli_support::Bindgen;
+use wasm_opt::OptimizationOptions;
 
 pub async fn front(
     proj: &Arc<Project>,
@@ -28,7 +24,7 @@ pub async fn front(
     let changes = changes.clone();
     tokio::spawn(async move {
         if !changes.need_front_build() {
-            log::trace!("Front no changes to rebuild");
+            trace!("Front no changes to rebuild");
             return Ok(Outcome::Success(Product::None));
         }
 
@@ -36,14 +32,14 @@ pub async fn front(
 
         let (envs, line, process) = front_cargo_process("build", true, &proj)?;
 
-        log::debug!("Running {}", GRAY.paint(&line));
+        debug!("Running {}", GRAY.paint(&line));
         match wait_interruptible("Cargo", process, Interrupt::subscribe_any()).await? {
             CommandResult::Interrupted => return Ok(Outcome::Stopped),
             CommandResult::Failure(_) => return Ok(Outcome::Failed),
             _ => {}
         }
-        log::debug!("Cargo envs: {}", GRAY.paint(envs));
-        log::info!("Cargo finished {}", GRAY.paint(line));
+        debug!("Cargo envs: {}", GRAY.paint(envs));
+        info!("Cargo finished {}", GRAY.paint(line));
 
         bindgen(&proj).await.dot()
     })
@@ -106,9 +102,8 @@ pub fn build_cargo_front_cmd(
 
 async fn bindgen(proj: &Project) -> Result<Outcome<Product>> {
     let wasm_file = &proj.lib.wasm_file;
-    let interrupt = Interrupt::subscribe_any();
 
-    log::info!("Front generating JS/WASM with wasm-bindgen");
+    info!("Front generating JS/WASM with wasm-bindgen");
 
     let start_time = tokio::time::Instant::now();
     // see:
@@ -120,21 +115,23 @@ async fn bindgen(proj: &Project) -> Result<Outcome<Product>> {
         .input_path(&wasm_file.source)
         .out_name(&proj.lib.output_name)
         .web(true)
-        .dot()?
+        .dot_anyhow()?
         .generate_output()
-        .dot()?;
+        .dot_anyhow()?;
 
     let bindgen_generate_end_time = tokio::time::Instant::now();
 
-    log::debug!(
+    debug!(
         "Finished generating wasm-bindgen output in {:?}",
         bindgen_generate_end_time - start_time
     );
 
-    bindgen.emit(wasm_file.dest.clone().without_last()).dot()?;
+    bindgen
+        .emit(wasm_file.dest.clone().without_last())
+        .dot_anyhow()?;
 
     let bindgen_emit_end_time = tokio::time::Instant::now();
-    log::debug!(
+    debug!(
         "Finished emitting wasm-bindgen in {:?}",
         bindgen_emit_end_time - bindgen_generate_end_time
     );
@@ -153,15 +150,11 @@ async fn bindgen(proj: &Project) -> Result<Outcome<Product>> {
     .dot()?;
 
     if proj.release {
-        match optimize(&wasm_file.dest, interrupt).await.dot()? {
-            CommandResult::Interrupted => return Ok(Outcome::Stopped),
-            CommandResult::Failure(_) => return Ok(Outcome::Failed),
-            _ => {}
-        }
+        optimize(&wasm_file.dest)?;
     }
 
     let wasm_optimize_end_time = tokio::time::Instant::now();
-    log::debug!(
+    debug!(
         "Finished optimizing WASM in {:?}",
         wasm_optimize_end_time - bindgen_emit_end_time
     );
@@ -179,13 +172,13 @@ async fn bindgen(proj: &Project) -> Result<Outcome<Product>> {
     };
 
     let js_minify_end_time = tokio::time::Instant::now();
-    log::debug!(
+    debug!(
         "Finished minifying JS in {:?}",
         js_minify_end_time - wasm_optimize_end_time
     );
 
     let front_end_time = tokio::time::Instant::now();
-    log::info!(
+    info!(
         "Finished generating JS/WASM for front in {:?}",
         front_end_time - start_time
     );
@@ -193,44 +186,40 @@ async fn bindgen(proj: &Project) -> Result<Outcome<Product>> {
     Ok(Outcome::Success(Product::Front))
 }
 
-async fn optimize(
-    file: &Utf8Path,
-    interrupt: broadcast::Receiver<()>,
-) -> Result<CommandResult<()>> {
-    let wasm_opt = Exe::WasmOpt.get().await.dot()?;
-
-    let args = [file.as_str(), "-Oz", "-o", file.as_str()];
-    let process = Command::new(wasm_opt)
-        .args(args)
-        .spawn()
-        .context("Could not spawn command")?;
-    wait_interruptible("wasm-opt", process, interrupt).await
+fn optimize(file: &Utf8Path) -> Result<()> {
+    OptimizationOptions::new_optimize_for_size_aggressively()
+        .run(file, file)
+        .dot()
 }
 
 fn minify<JS: AsRef<str>>(js: JS) -> Result<String> {
     let cm = Arc::<SourceMap>::default();
 
     let c = swc::Compiler::new(cm.clone());
-    let output = GLOBALS.set(&Default::default(), || {
-        try_with_handler(cm.clone(), Default::default(), |handler| {
-            let fm = cm.new_source_file(Arc::new(FileName::Anon), js.as_ref().to_string());
+    let output = GLOBALS
+        .set(&Default::default(), || {
+            try_with_handler(cm.clone(), Default::default(), |handler| {
+                let fm = cm.new_source_file(Arc::new(FileName::Anon), js.as_ref().to_string());
 
-            c.minify(
-                fm,
-                handler,
-                &JsMinifyOptions {
-                    compress: BoolOrDataConfig::from_bool(true),
-                    mangle: BoolOrDataConfig::from_bool(true),
-                    // keep_classnames: true,
-                    // keep_fnames: true,
-                    module: IsModule::Bool(true),
-                    ..Default::default()
-                },
-                JsMinifyExtras::default(),
-            )
-            .context("failed to minify")
+                use anyhow::Context;
+
+                c.minify(
+                    fm,
+                    handler,
+                    &JsMinifyOptions {
+                        compress: BoolOrDataConfig::from_bool(true),
+                        mangle: BoolOrDataConfig::from_bool(true),
+                        // keep_classnames: true,
+                        // keep_fnames: true,
+                        module: IsModule::Bool(true),
+                        ..Default::default()
+                    },
+                    JsMinifyExtras::default(),
+                )
+                .context("failed to minify")
+            })
         })
-    })?;
+        .wrap_anyhow_err("Failed to minify")?;
 
     Ok(output.code)
 }
