@@ -1,24 +1,27 @@
-use anyhow::Result;
+use camino::Utf8Path;
 use tokio::process::Command;
 
+use crate::internal_prelude::*;
 use crate::{
     config::{Project, TailwindConfig},
     ext::{
-        anyhow::Context,
+        color_eyre::CustomWrapErr,
         fs,
         sync::{wait_piped_interruptible, CommandResult, OutputExt},
-        Exe,
+        Exe, Paint,
     },
     logger::GRAY,
     signal::{Interrupt, Outcome},
 };
 
 pub async fn compile_tailwind(proj: &Project, tw_conf: &TailwindConfig) -> Result<Outcome<String>> {
-    if !tw_conf.config_file.exists() {
-        create_default_tailwind_config(tw_conf).await?;
+    if let Some(config_file) = tw_conf.config_file.as_ref() {
+        if !config_file.exists() {
+            create_default_tailwind_config(config_file).await?
+        }
     }
 
-    let (line, process) = tailwind_process(&proj, "tailwindcss", tw_conf).await?;
+    let (line, process) = tailwind_process(proj, "tailwindcss", tw_conf).await?;
 
     match wait_piped_interruptible("Tailwind", process, Interrupt::subscribe_any()).await? {
         CommandResult::Success(output) => {
@@ -30,23 +33,23 @@ pub async fn compile_tailwind(proj: &Project, tw_conf: &TailwindConfig) -> Resul
                 .unwrap_or(false);
 
             if done {
-                log::info!("Tailwind finished {}", GRAY.paint(line));
+                info!("Tailwind finished {}", GRAY.paint(line));
                 match fs::read_to_string(&tw_conf.tmp_file).await {
                     Ok(content) => Ok(Outcome::Success(content)),
                     Err(e) => {
-                        log::error!("Failed to read tailwind result: {e}");
+                        error!("Failed to read tailwind result: {e}");
                         Ok(Outcome::Failed)
                     }
                 }
             } else {
-                log::warn!("Tailwind failed {}", GRAY.paint(line));
+                warn!("Tailwind failed {}", GRAY.paint(line));
                 println!("{}\n{}", output.stdout(), output.stderr());
                 Ok(Outcome::Failed)
             }
         }
         CommandResult::Interrupted => Ok(Outcome::Stopped),
         CommandResult::Failure(output) => {
-            log::warn!("Tailwind failed");
+            warn!("Tailwind failed");
             if output.has_stdout() {
                 println!("{}", output.stdout());
             }
@@ -56,7 +59,7 @@ pub async fn compile_tailwind(proj: &Project, tw_conf: &TailwindConfig) -> Resul
     }
 }
 
-async fn create_default_tailwind_config(tw_conf: &TailwindConfig) -> Result<()> {
+async fn create_default_tailwind_config(config_file: &Utf8Path) -> Result<()> {
     let contents = r#"/** @type {import('tailwindcss').Config} */
     module.exports = {
       content: {
@@ -69,7 +72,7 @@ async fn create_default_tailwind_config(tw_conf: &TailwindConfig) -> Result<()>
       plugins: [],
     }
     "#;
-    fs::write(&tw_conf.config_file, contents).await
+    fs::write(config_file, contents).await
 }
 
 pub async fn tailwind_process(
@@ -79,14 +82,15 @@ pub async fn tailwind_process(
 ) -> Result<(String, Command)> {
     let tailwind = Exe::Tailwind.get().await.dot()?;
 
-    let mut args: Vec<&str> = vec![
-        "--input",
-        tw_conf.input_file.as_str(),
-        "--config",
-        tw_conf.config_file.as_str(),
-        "--output",
-        tw_conf.tmp_file.as_str(),
-    ];
+    let mut args = vec!["--input", tw_conf.input_file.as_str()];
+
+    if let Some(config_file) = tw_conf.config_file.as_ref() {
+        args.push("--config");
+        args.push(config_file.as_str());
+    }
+
+    args.push("--output");
+    args.push(tw_conf.tmp_file.as_str());
 
     if proj.release {
         // minify & optimize
